@@ -270,23 +270,16 @@ class TestBoxFunctional:
         with pytest.raises(BoxError) as err:
             Box.from_json()
 
-        assert 'requires' in str(err)
-
         with pytest.raises(BoxError) as err2:
             Box.from_json(json_string="[1]")
 
-        assert 'dict' in str(err2)
-
     def test_bad_from_yaml(self):
         with pytest.raises(BoxError) as err:
             Box.from_yaml()
-        assert 'requires' in str(err)
 
         with pytest.raises(BoxError) as err2:
             Box.from_yaml('lol')
 
-        assert 'dict' in str(err2)
-
     def test_conversion_box(self):
         bx = Box(extended_test_dict, conversion_box=True)
         assert bx.Key_2.Key_3 == "Value 3"
@@ -544,7 +537,6 @@ class TestBoxFunctional:
     def test_duplicate_errors(self):
         with pytest.raises(BoxError) as err:
             Box({"?a": 1, "!a": 3}, box_duplicates="error")
-        assert "Duplicate" in str(err)
 
         Box({"?a": 1, "!a": 3}, box_duplicates="ignore")
 
